unit Unit1;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls, Vcl.ExtCtrls;

type
  TForm1 = class(TForm)
    Panel1: TPanel;
    CBSeries: TComboBox;
    CBSeriesActive: TCheckBox;
    BFillSampleValues: TButton;
    CBOtherSide: TCheckBox;
    procedure FormCreate(Sender: TObject);
    procedure CBSeriesChange(Sender: TObject);
    procedure CBSeriesActiveClick(Sender: TObject);
    procedure BFillSampleValuesClick(Sender: TObject);
    procedure BAddSeriesClick(Sender: TObject);
    procedure CBOtherSideClick(Sender: TObject);
  private
    { Private declarations }
    procedure PlaceAxes(nSeries: Integer=0; NextXLeft: Integer=0; NextXRight: Integer=0; MargLeft: Integer=0; MargRight: Integer=0);
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

uses Chart, Series, TeeProcs;

var Chart1: TChart;

procedure TForm1.FormCreate(Sender: TObject);
var i: Integer;
const nSeries = 4;
begin
  CBSeries.Items.Clear;

  Chart1:=TChart.Create(Self);

  with Chart1 do
  begin
    Parent:=Self;
    Align:=alClient;
    Color:=clWhite;
    Gradient.Visible:=False;
    Walls.Back.Color:=clWhite;
    Walls.Back.Gradient.Visible:=False;
    Legend.Hide;
    View3D:=False;
  end;

  for i := 0 to nSeries-1 do
  begin
    Chart1.AddSeries(TLineSeries);
    Chart1.CustomAxes.Add;
    Chart1[i].CustomVertAxis := Chart1.CustomAxes.Items[i];
    Chart1.CustomAxes.Items[i].Axis.Color := Chart1[i].Color;
    Chart1.CustomAxes.Items[i].Grid.Visible := False;
    CBSeries.Items.Add('Series' + inttostr(i + 1));
    Chart1[i].FillSampleValues(500);
    Chart1.CustomAxes.Items[i].PositionUnits := muPixels;
    if ((i+1) mod 2 = 0) then
      Chart1.CustomAxes.Items[i].OtherSide := True;
  end;

  Chart1.MarginUnits := muPixels;

  CBSeries.ItemIndex := 0;
  CBSeriesActive.Checked := True;
  CBOtherSide.Checked := Chart1.CustomAxes.Items[0].OtherSide;

  Chart1.Draw;
  PlaceAxes();
end;

procedure TForm1.PlaceAxes(nSeries: Integer=0; NextXLeft: Integer=0; NextXRight: Integer=0; MargLeft: Integer=0; MargRight: Integer=0);
const extraPos = 12;
const extraMargin = 45;
begin
  if Chart1[nSeries].Active then
  begin
    if Chart1.CustomAxes.Items[nSeries].OtherSide then
    begin
      Chart1.CustomAxes.Items[nSeries].PositionPercent := NextXRight;
      NextXRight := NextXRight - Chart1.CustomAxes.Items[nSeries].MaxLabelsWidth - Chart1.CustomAxes.Items[nSeries].TickLength - extraPos;
      MargRight := MargRight + extraMargin;
    end
    else
    begin
      Chart1.CustomAxes.Items[nSeries].PositionPercent := NextXLeft;
      NextXLeft := NextXLeft - Chart1.CustomAxes.Items[nSeries].MaxLabelsWidth - Chart1.CustomAxes.Items[nSeries].TickLength - extraPos;
      MargLeft := MargLeft + extraMargin;
    end;
  end;

  Chart1.MarginLeft := MargLeft;
  Chart1.MarginRight := MargRight;

  nSeries := nSeries + 1;

  if nSeries <= Chart1.SeriesCount - 1 then
     PlaceAxes(nSeries, NextXLeft, NextXRight, MargLeft, MargRight);
end;

procedure TForm1.CBSeriesActiveClick(Sender: TObject);
begin
  Chart1[CBSeries.ItemIndex].Active := CBSeriesActive.Checked;
  PlaceAxes();
end;

procedure TForm1.CBOtherSideClick(Sender: TObject);
begin
  Chart1.CustomAxes.Items[CBSeries.ItemIndex].OtherSide := CBOtherSide.Checked;
  PlaceAxes();
end;

procedure TForm1.CBSeriesChange(Sender: TObject);
begin
  CBSeriesActive.Checked := Chart1[CBSeries.ItemIndex].Active;
  CBOtherSide.Checked := Chart1.CustomAxes.Items[CBSeries.ItemIndex].OtherSide;
end;

procedure TForm1.BFillSampleValuesClick(Sender: TObject);
var i: Integer;
begin
  for i := 0 to Chart1.SeriesCount-1 do
      Chart1[i].FillSampleValues(100);

  PlaceAxes();
end;

procedure TForm1.BAddSeriesClick(Sender: TObject);
begin
  Chart1.AddSeries(TLineSeries);
  Chart1.CustomAxes.Add;
  Chart1.CustomAxes.Items[Chart1.CustomAxes.Count-1].PositionUnits := muPixels;
  Chart1[Chart1.SeriesCount-1].CustomVertAxis := Chart1.CustomAxes.Items[Chart1.CustomAxes.Count-1];

  if (Chart1.CustomAxes.Count mod 2 = 0) then
      Chart1.CustomAxes.Items[Chart1.CustomAxes.Count-1].OtherSide := True;

  Chart1.CustomAxes.Items[Chart1.CustomAxes.Count-1].Axis.Color := Chart1[Chart1.SeriesCount-1].Color;
  Chart1.CustomAxes.Items[Chart1.CustomAxes.Count-1].Grid.Visible := False;
  CBSeries.Items.Add('Series' + inttostr(Chart1.SeriesCount));
  CBSeries.ItemIndex := CBSeries.Items.Count-1;
  Chart1[Chart1.SeriesCount-1].FillSampleValues(Chart1[0].XValues.Count);
  PlaceAxes();
end;
end.
